阿凡达 (豆瓣)
Description: 阿凡达电影简介和剧情介绍,阿凡达影评、图片、预告片、影讯、论坛、在线购票
Keywords: 阿凡达,Avatar,阿凡达影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.75豆瓣电影Top250

# 阿凡达 Avatar (2009)

导演: 詹姆斯·卡梅隆
编剧: 詹姆斯·卡梅隆
主演: 萨姆·沃辛顿 / 佐伊·索尔达娜 / 西格妮·韦弗 / 史蒂芬·朗 / 米歇尔·罗德里格兹 / 吉奥瓦尼·瑞比西 / 乔·大卫·摩尔 / 希·庞德 / 韦斯·斯塔迪 / 拉兹·阿隆索 / 迪利普·劳 / 马特·杰拉德 / 肖恩·安东尼·莫兰
类型: 动作 / 科幻 / 冒险
官方网站: www.avatarmovie.com
制片国家/地区: 美国
语言: 英语 / 西班牙语
上映日期: 2010-01-04(中国大陆) / 2021-03-12(中国大陆重映) / 2009-12-18(美国)
片长: 162分钟 / 178分钟(加长版)
又名: 天神下凡(港) / 化身 / 异次元战神 / 神之化身
IMDb: tt0499549
豆瓣评分
引用
8.8
1315986人评价
5星
53.7%
4星
35.1%
3星
10.1%
2星
0.8%
1星
0.3%
好于 98% 科幻片
好于 99% 动作片
想看 看过
评价:
推荐

## 阿凡达的剧情简介 · · · · · ·

战斗中负伤而下身瘫痪的前海军战士杰克·萨利（萨姆·沃辛顿 Sam Worthington 饰）决定替死去的同胞哥哥来到潘多拉星操纵格蕾丝博士（西格妮·韦弗 Sigourney Weaver 饰）用人类基因与当地纳美部族基因结合创造出的 “阿凡达” 混血生物。杰克的目的是打入纳美部落，外交说服他们自愿离开世代居住的家园，从而SecFor公司可砍伐殆尽该地区的原始森林，开采地下昂贵的“不可得”矿。在探索潘多拉星的过程中，杰克遇到了纳美部落的公主娜蒂瑞（佐伊·索尔达娜 Zoe Saldana 饰），向她学习了纳美人的生存技能与对待自然的态度。与此同时，SecFor公司的经理和军方代表上校迈尔斯（史蒂芬·朗 Stephen Lang 饰）逐渐丧失耐心，决定诉诸武力驱赶纳美人……
本片采用3D技术拍摄，共耗资5亿美元制作发行，是电影史上最为昂贵的作品。本片荣获... (展开全部) 战斗中负伤而下身瘫痪的前海军战士杰克·萨利（萨姆·沃辛顿 Sam Worthington 饰）决定替死去的同胞哥哥来到潘多拉星操纵格蕾丝博士（西格妮·韦弗 Sigourney Weaver 饰）用人类基因与当地纳美部族基因结合创造出的 “阿凡达” 混血生物。杰克的目的是打入纳美部落，外交说服他们自愿离开世代居住的家园，从而SecFor公司可砍伐殆尽该地区的原始森林，开采地下昂贵的“不可得”矿。在探索潘多拉星的过程中，杰克遇到了纳美部落的公主娜蒂瑞（佐伊·索尔达娜 Zoe Saldana 饰），向她学习了纳美人的生存技能与对待自然的态度。与此同时，SecFor公司的经理和军方代表上校迈尔斯（史蒂芬·朗 Stephen Lang 饰）逐渐丧失耐心，决定诉诸武力驱赶纳美人……
本片采用3D技术拍摄，共耗资5亿美元制作发行，是电影史上最为昂贵的作品。本片荣获第82届奥斯卡最佳摄影、最佳视觉效果、最佳艺术指导等3项大奖。 ©豆瓣

## 阿凡达的演职员 · · · · · · ( 全部 48 )

- 詹姆斯·卡梅隆 导演
- 萨姆·沃辛顿 饰 杰克·萨利 Jake Sully
- 佐伊·索尔达娜 饰 Neytiri
- 西格妮·韦弗 饰 格蕾丝·奥古斯汀博士 Dr. Grace Augustine
- 史蒂芬·朗 饰 迈尔斯·夸里奇上校 Colonel Miles Quaritch
- 米歇尔·罗德里格兹 饰 楚蒂·查孔 Trudy Chacón

## 阿凡达的视频和图片 · · · · · · ( 预告片6 | 视频评论1 · 添加 | 图片1053 · 添加 )

## 阿凡达的获奖情况 · · · · · · ( 全部 )

- 第82届奥斯卡金像奖
- 最佳影片(提名)
- 詹姆斯·卡梅隆 / 乔恩·兰道

- 第67届威尼斯电影节
- 3-D电影奖 年度最具创意立体电影
- 詹姆斯·卡梅隆

- 第67届金球奖
- 电影类 最佳剧情片

## 喜欢这部电影的人也喜欢 · · · · · ·

  黑客帝国

  盗梦空间

  变形金刚

  星际穿越

  终结者2：审判日

  头号玩家

  E.T.外星人

  钢铁侠

  第九区

  源代码

我要写短评

## 阿凡达的短评 · · · · · · ( 全部 249151 条 )

热门 / 最新 / 好友

### 1166 有用 prost 看过 2009-12-23 06:48:33

印第安在白人领导下的反白人入侵战争，可惜史实与此相反

### 8209 有用 Menphis 看过 2009-12-17 01:37:25

钉子户 大战 城管 in 3D

### 6826 有用 不体面james 看过 2009-12-18 07:42:44

当所有美国大片都开始炫耀自己的视觉效果时，詹姆斯卡梅隆只是坐在阴暗的角落里冷笑，然后抛出这么一部让所有人感慨“操，真他妈牛逼啊！”的电影。

### 5177 有用 圣约血镰 看过 2009-12-17 00:05:47

抱歉，2012？在Avatar面前不过是小儿科！ 只有一句话：这是史上最强科幻！ 可恶的卡梅隆，你要让未来十年的所有科幻片都味同嚼蜡了！ 因为所有观众的审美标准已经一口气被你提高了几个档次！ 这部电影，不去剧院看绝对一辈子后悔 最后，感谢上帝赐给我们一个James Cameron

### 5678 有用 皮革业 看过 2009-12-23 13:17:28

James Cameron闭上眼，全是电影的明天。

> 更多短评 249151条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 阿凡达的影评 · · · · · · ( 全部 5173 条 )

热门 / 最新 / 好友
spencer 2010-01-06 09:50:38

## 一封迟到500年的道歉信，3D的

“如果我们放弃这片土地，转让给你们，你们一定要记住：这片土地是神圣的。” 　　 　　1854年，一位印第安人酋长给“在华盛顿特区的大首领”写下这句话。他与他的族人已经拼尽了最后的一分力量，年轻的猎手们已牺牲殆尽，年老体弱者被疾病缠身……没有人听到他们的哀嚎与... (展开)
7282 273 730回应 收起
祥瑞御兔 2009-12-20 09:32:49

## 《阿凡达》：一次伟大的反拆迁斗争

这篇影评可能有剧透

（引自《星际百科全书》第六版第1984卷“星际拆迁”条目下义项“原住民的反拆迁斗争”中的有关内容，本条目由著名拆迁史学家William Zhang博士撰写，唐福珍女士对此条目亦有贡献，未经许可不得私自转载、引用） ……但是，在人类为牟求经济利益，不顾原住民意愿而强行进行的... (展开)
2047 173 518回应 收起
鱼非鱼 2010-01-08 12:52:41

## 各版本效果比较|3D放映技术扫盲|各地推荐影城(9.10更新)

------本文作者为鱼非鱼，转载请注明------ --阿凡达各种版本综合评分（不考虑银幕大小和座位情况）， 我会根据大家反映的情况进行微调 IMAX数字&金属幕 100 IMAX胶片&金属幕 100 双机3D&金属幕 100 IMAX数字&白幕 ... (展开)
1100 28 321回应 收起
TORO VAN DARKO 2009-12-16 09:43:05

## 如有雷同，绝非巧合

【如果你跟我一样，那不是巧合】 从2006年8月6日，卡梅隆宣布正式启动AVATAR拍摄计划开始，无数影迷就一直翘首期盼。我们关注关于这部电影的每一条新闻每一个细枝末节的动态报道，因为我们都坚信，这将是一部被载入电影技术发展史的神作。 2009年8月20日，这一天被定为... (展开)
1046 79 427回应 收起
艾小柯 2009-12-21 18:04:23

## 好莱坞电影的崭新时代

用“开启好莱坞电影的崭新时代”来总结《阿凡达》，我想并不为过。 这部卡梅隆耗时4年半制作，总斥资接近5亿美元打造的《阿凡达》不仅开辟了电影3D技术的新天地，其带给人的视听感受也是划时代的。它将一度被家庭投影和蓝光高清DVD狠狠冲击的电影院们终于拉回到了影迷视线的焦... (展开)
487 108 186回应 收起
叶子风 2010-01-06 09:45:52

## 阿凡达：文明的野蛮人

1.观影前很不幸，先看到陆川撰文盛赞《阿凡达》。陆川是施虐狂，喜欢残酷和血腥，并且很知识分子，热衷于将自己的怪癖包装成“理想主义”。这种人是天朝极品，从《可可西里》的“环保”到《南京南京》“反战”，都是主旋律。他赞美《阿凡达》，给我带来了某种不祥的预感... (展开)
1052 652 435回应 收起
梨 2021-03-23 12:21:46

## 重映了才发现《阿凡达》院线字幕问题那么大

这篇影评可能有剧透

这次《阿凡达》重映，据说用的是初版字幕。看完电影我很迷惑，因为 2010 年看的时候，我并不记得字幕翻译的问题有那、么、多。 可能是中学时期我英语还不够好吧。 于是写了这篇文章，记录 1）影响剧情理解的错译 2）拉低观影感受的漏译 3）值得讨论的翻译抉择，一共 27 处。 进... (展开)
511 4 84回应 收起
图宾根木匠 2010-01-04 14:10:35

## 不要迷恋《阿凡达》

这篇影评可能有剧透

不要迷恋《阿凡达》，对中国电影人来说，那只是个遥不可及的传说——以我有限的智商推断，在可以预见的将来，《阿凡达》对我们的“遥不可及”几乎是无限的。 我们看的也并不是《阿凡达》，而是一个名叫詹姆斯•卡梅隆的怪蜀黍长达十三年的寂寞。 技术上的细节我并不掌握，不... (展开)
324 55 138回应 收起
Evarnold 2010-01-25 19:01:48

## 眼里心里和梦里的创世福音——写在《阿凡达》即将破船之际

眼里心里和梦里的创世福音 ——写在《阿凡达》即将破船之际 【负一】献给卡神 这篇文章从2010年1月4日写到2010年1月25日。 期间，共看《阿凡达》四次，IMAX 3D两次，数字3D两次，至今包括请客在内共贡献票房880元人民币。 献给所有挚爱《阿凡达》的影迷。 献给刚刚击沉《... (展开)
236 25 150回应 收起
开树的花 2009-12-21 01:48:54

## 《阿凡达》：最想环游的世界，我曾存在150分钟

观影时间：12月17日9：00am。 观影地点：HK尖沙咀UA。 观影版本：IMAX 3D。 稍微对电影有点兴趣的人都知道内地元月将有一部科幻大片《阿凡达》上映，听说很好看。还有一些不那么关心电影的人，扫一眼网络上公交站牌上的广告，以为《泰坦尼克号》的导演花了12年时间翻拍... (展开)
252 35 174回应 收起

> 更多影评 5173篇

添加新讨论

## 讨论区 · · · · · ·

这种垃圾电影在国内还被人吹真他妈是耻辱。 | 来自王北 | 3 回应 | 2022-11-24 14:31:51
虽然我知道这是人类的一场错误的侵略，但是我心里... | 来自豆友szQo1CjF9Q | 1 回应 | 2022-11-23 13:50:50
小谈 | 来自佛尔斯特 |  | 2022-11-20 21:31:20
从高一理科生角度来看，阿凡达的主角其实就是人类... | 来自啦啦啦 | 42 回应 | 2022-11-19 22:44:38
重制版9月在美国上映，国内还会再引进吗？ | 来自豆8 | 8 回应 | 2022-11-18 15:36:05

> 去这部影片的讨论区（全部2277条）

## 关于《阿凡达》的问题 · · · · · · ( 全部19个 )

- 为啥酋长允许男主留在部落？ 2人回答
- 男主的蓝色躯体是怎么来的？ 1人回答

> 全部19个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 单片付费
- 芒果TV VIP免费观看
- 腾讯视频 单片付费
- 西瓜视频 单片付费

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- {北美电影票房总排行} (荔枝超人)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)
- 有生之年非看不可的1001部电影 (Viking)
- IMDb科幻电影Top200 (等一个人)

## 谁在看这部电影 · · · · · ·

- Monster
  刚刚 看过
- 子时当归
  刚刚 看过
- Silbermondemon
  1分钟前 想看

2555885人看过 / 177436人想看

订阅阿凡达的评论:
feed: rss 2.0